@@ -426,7 +426,7 @@
 		(when (and (eq? return-type 'double)
 			   (< num-args 5)
 			   (sig-every? (lambda (p) (eq? p 'double)) arg-types)
-			   (not (defined? (symbol scheme-name) rootlet))) ; see below, double-funcs entry not used if already defined
+			   (not (defined? (symbol scheme-name) (rootlet)))) ; see below, double-funcs entry not used if already defined
 		  (let ((local-name #f))
 		    (case num-args
 		      ((0)
@@ -450,9 +450,9 @@
 		       (format pp "static s7_double ~A~A(s7_double x1, s7_double x2, s7_double x3, s7_double x4) {return(~A(x1, x2, x3, x4));}~%"
 			       func-name local-name func-name)))
 		    (set! double-funcs (cons (list func-name scheme-name local-name) double-funcs))))
-		
+
 		(when (and (memq return-type '(int size_t))        ; int (f int|double|void)
-			   (not (defined? (symbol scheme-name) rootlet)) ; see below, int-funcs entry not used if already defined
+			   (not (defined? (symbol scheme-name) (rootlet))) ; see below, int-funcs entry not used if already defined
 			   (or ;(= num-args 0)
 			    (and (= num-args 1)
 				 (memq (car arg-types) '(int size_t double)))
@@ -487,6 +487,7 @@
 		;; other possibilities: d_7pi|pii p=double* etc piid=checks in s7 (assumes float-vector)
 		;;   d_pd [lots of d_pdd, d_p, p_i and i_p]
 		;;   but how to recognize the "p" portions? (d_7pi with p="s7_pointer" gets no hits in libgsl)
+		;; libgsl: d_i: 15, d_ii: 5, [handled: d_id: 32], d_iid: 7, d_ddi: 4, d_idd: 10, d_idi: 6, i_ddd i_iii: 1, i_dddd: 4
 		
 		(format pp "~%")
 		(set! functions (cons (list scheme-name base-name 
