@@ -247,7 +247,7 @@
 	     (obank (make-oscil-bank lastfreq (make-float-vector N2) lastamp))
 	     (filptr 0)
 	     (D (floor (/ fftsize overlap)))
-	     (syngate (if (= 0.0 gate)    ; take a resynthesis gate specificed in dB, convert to linear amplitude
+	     (syngate (if (= 0.0 gate)    ; take a resynthesis gate specified in dB, convert to linear amplitude
 			  0.0000
 			  (expt 10 (/ (- (abs gate)) 20))))
 	     (poffset (hz->radians hoffset))
