@@ -416,8 +416,6 @@ void snd_set_global_defaults(bool need_cleanup)
   ss->auto_resize_symbol =           s7_define_variable(s7, "*" S_auto_resize "*",            s7_make_boolean(s7, DEFAULT_AUTO_RESIZE));
 #if USE_MOTIF
   #define DEFAULT_LISTENER_FONT "9x15"
-#endif
-#if (!USE_NO_GUI)
   ss->listener_font_symbol =         s7_define_variable(s7, "*" S_listener_font "*",          s7_make_string(s7, DEFAULT_LISTENER_FONT));
 #else
   ss->listener_font_symbol =         s7_define_variable(s7, "*" S_listener_font "*",          s7_make_string(s7, ""));
@@ -508,9 +506,6 @@ void snd_set_global_defaults(bool need_cleanup)
   ss->axis_color_symbol           = s7_define_variable(s7, "*" S_axis_color "*",           s7_f(s7));
 
   ss->transform_type_symbol = s7_define_variable(s7, "*" S_transform_type "*", s7_f(s7)); /* set in snd-chn.c(!) */
-#if USE_GTK
-  ss->listener_colorized_symbol = s7_define_variable(s7, "*listener-colorized*", s7_make_boolean(s7, s7_f(s7)));
-#endif
 #endif
 }
 
@@ -553,12 +548,6 @@ int main(int argc, char **argv)
   ss = (snd_state *)calloc(1, sizeof(snd_state)); /* not calloc! */
   ss->startup_errors = NULL;
 
-#if USE_GTK
-#if GTK_CHECK_VERSION(3, 0, 0) && (!GLIB_CHECK_VERSION(2,35,0))
-  g_type_init();
-#endif
-#endif
-
   mus_sound_initialize(); /* has to precede version check (mus_audio_moniker needs to be setup in Alsa/Oss) */
   xen_initialize();
 
