@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "27-Nov-23"
+#define SND_DATE "2-Feb-24"
 #ifndef SND_VERSION
-#define SND_VERSION "23.9"
+#define SND_VERSION "24.1"
 #endif
-#define SND_MAJOR_VERSION "23"
-#define SND_MINOR_VERSION "9"
+#define SND_MAJOR_VERSION "24"
+#define SND_MINOR_VERSION "1"
 
 #endif
