@@ -8,10 +8,10 @@
 	  (let ((words (make-hash-table))
 		(cur-word (make-string 512))
 		(word "")
-		(cur-loc 0)
 		(cur-line 1)
 		(last-c #\null))
-	    (do ((c (read-char ip) (read-char ip)))
+	    (do ((cur-loc 0)
+		 (c (read-char ip) (read-char ip)))
 		((eof-object? c)
 		 (for-each (lambda (w)
 			     (format op "~A: ~S~%" (car w) (reverse (cdr w))))
@@ -56,6 +56,7 @@
 				       (cons cur-line (or (hash-table-ref words word) ()))))
 		    (set! cur-loc 0))))))))))
 
+
 ;;; --------------------------------
 
 (define (searcher)
