@@ -1,16 +1,16 @@
 (define (no-dashes-or-cr str)
-  (let ((len (length str))
-	(newstr "")
-	(last-ch #\-))
-    (do ((i 0 (+ i 1)))
-	((= i (- len 1)))
-      (let ((ch (string-ref str i)))
-	(if (and (or (not (char=? ch #\-))
-		     (char-alphabetic? last-ch))
-		 (not (char=? ch #\newline)))
-	    (set! newstr (string-append newstr (make-string 1 ch))))
-	(set! last-ch ch)))
-    newstr))
+  (do ((len (length str))
+       (newstr "")
+       (last-ch #\-)
+       (i 0 (+ i 1)))
+      ((= i (- len 1)) 
+       newstr)
+    (let ((ch (string-ref str i)))
+      (if (and (or (not (char=? ch #\-))
+		   (char-alphabetic? last-ch))
+	       (not (char=? ch #\newline)))
+	  (set! newstr (string-append newstr (make-string 1 ch))))
+      (set! last-ch ch))))
 
 (let ((ctr 0))
   (call-with-input-file 
