@@ -112,12 +112,13 @@
 	(catch #t (lambda () (format #f ctrl-str z y x)) (lambda arg 'error))))))
 
 (define (test-chars)
-  (let ((op (open-output-string)))
+  (let ((op (open-output-string))
+	(total-size 15))
     (do ((size 2 (+ size 1))
 	 (size1 3 (+ size1 1))
 	 (tries 4000 (+ tries 2000))
-	 (ctrl-str (make-string 16 #\space)))
-	((= size 15))
+	 (ctrl-str (make-string (+ total-size 1) #\space)))
+	((= size total-size))
       (format *stderr* "~D " size)
       (string-set! ctrl-str size1 #\null)
       (string-set! ctrl-str 0 #\~)
