@@ -8,7 +8,7 @@
 (define (va)
   (for-each
    (lambda (func)
-     (system (format #f "fgrep ~A *.c > vahi" func))
+     (system (format #f "grep -F ~A *.c > vahi" func))
      (call-with-input-file "vahi"
        (lambda (file)
 	 (let loop ((line (read-line file #t)))
@@ -100,7 +100,7 @@
   (for-each
    (lambda (file)
      (if (and (not (directory? file))
-	      (not (zero? (system (format #f "fgrep ~A *.html" file)))))
+	      (not (zero? (system (format #f "grep -F ~A *.html" file)))))
 	 (set! baddies (cons file baddies))))
    png-files)
   (if (not (null? baddies))
